![perclock](https://github.com/1darshanpatil/percentum/assets/72539638/6ee23d37-6f33-49ff-8182-9909325f7ecc)



# Percentum

---

**percentum** is a Python command-line interface (CLI) package designed to provide a clear perception of time in terms of hours, minutes, and working hours as a percentage of total time.

The primary intention behind creating and publishing this package is to assist individuals who tend to be workaholics and often lose track of time. They may find themselves immersed in work, losing sight of the passage of time. This phenomenon is well-explained in [Psychology Stack Exchange](https://psychology.stackexchange.com/questions/27694/the-perception-of-time-of-workaholics).

The secondary purpose is that we often say, "What's the big deal? It's only 15 minutes." Essentially, we don't value time, as 14.4 minutes represent 1% of your day, and we all know that 1% is a significant portion.

## Usage

To use **percentum**, follow these simple steps:

1. Install the package:

   ```bash
   $ pip install percentum
   ```
2. Usage
    ```bash
    $ sand
    Time Used: |████████████████████████--------------------------| 48.91%
    ```



## License

percentum is released under the MIT License. See the [LICENSE](LICENSE) file for more details.
